@@ -1,4 +1,4 @@
-# $Id: wbug.py 1156 2014-12-03 19:44:45Z mwall $
+# $Id: wbug.py 1166 2014-12-06 22:49:33Z mwall $
 # Copyright 2013 Matthew Wall
 
 """
@@ -84,7 +84,7 @@ import weewx.restx
 import weewx.units
 from weeutil.weeutil import to_bool, accumulateLeaves, startOfDayUTC
 
-VERSION = "0.2"
+VERSION = "0.3"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -270,10 +270,10 @@ class WeatherBugThread(weewx.restx.RESTThread):
             (from_unit, _) = weewx.units.getStandardUnitType(
                 record['usUnits'], 'outTemp')
             if 'outTempMax' in rec and rec['outTempMax']:
-                from_t = (rec['outTempMax'], from_unit, 'group_rain')
+                from_t = (rec['outTempMax'], from_unit, 'group_temperature')
                 rec['outTempMax'] = weewx.units.convert(from_t, 'inch')[0]
             if 'outTempMin' in rec and rec['outTempMin']:
-                from_t = (rec['outTempMin'], from_unit, 'group_rain')
+                from_t = (rec['outTempMin'], from_unit, 'group_temperature')
                 rec['outTempMin'] = weewx.units.convert(from_t, 'inch')[0]
         return rec
 
